@@ -5,7 +5,6 @@ use 5.008;
 use strict;
 use warnings;
 use Carp;
-use Scalar::Util 'blessed';
 use constant PLACEHOLDER => "\x{b1}\x{a4}\x{221e}";
 
 # Common routines and variables exported to all DBO classes.
@@ -16,8 +15,11 @@ use subs qw(ouch oops);
 *ouch = \&Carp::croak;
 
 our %Config = (
-    QuoteIdentifier => 1,
+    AutoReconnect => 0,
     DebugSQL => 0,
+    QuoteIdentifier => 1,
+    RowClass => undef,
+    StoreRows => 0,
 );
 our @CARP_NOT;
 our $placeholder = PLACEHOLDER;
@@ -29,7 +31,7 @@ sub import {
     no strict 'refs';
     *{$caller.'::Config'} = \%{__PACKAGE__.'::Config'};
     *{$caller.'::CARP_NOT'} = \@{__PACKAGE__.'::CARP_NOT'};
-    for (qw(oops ouch blessed)) {
+    for (qw(oops ouch)) {
         *{$caller.'::'.$_} = \&{$_};
     }
 }
@@ -145,7 +147,7 @@ sub _build_show {
     return $h->{show} = $distinct.'*' unless @{$h->{Showing}};
     my @flds;
     for my $fld (@{$h->{Showing}}) {
-        push @flds, (blessed $fld and $fld->isa('DBIx::DBO::Table'))
+        push @flds, UNIVERSAL::isa($fld, 'DBIx::DBO::Table')
             ? $me->_qi($me->_table_alias($fld) || $fld->{Name}).'.*'
             : $me->_build_val($h->{Show_Bind}, @$fld);
     }
@@ -192,7 +194,7 @@ sub _valid_col {
 sub _parse_col {
     my ($me, $col, $_check_aliases) = @_;
     if (ref $col) {
-        return $me->_valid_col($col) if blessed $col and $col->isa('DBIx::DBO::Column');
+        return $me->_valid_col($col) if UNIVERSAL::isa($col, 'DBIx::DBO::Column');
         ouch 'Invalid column: '.$col;
     }
     # If $_check_aliases is not defined dont accept an alias
@@ -231,7 +233,7 @@ sub _parse_val {
         } else {
             $fld = exists $fld->{VAL} ? $fld->{VAL} : [];
         }
-    } elsif (blessed $fld and $fld->isa('DBIx::DBO::Column')) {
+    } elsif (UNIVERSAL::isa($fld, 'DBIx::DBO::Column')) {
         return [ $me->_valid_col($fld) ];
     }
     $fld = [$fld] unless ref $fld eq 'ARRAY';
@@ -250,7 +252,7 @@ sub _parse_val {
 sub _substitute_placeholders {
     my $me = shift;
     my $num_placeholders = 0;
-    $_[0] =~ s/((?<!\\)(['"`]).*?[^\\]\2|\?)/$1 eq '?' ? ++$num_placeholders && PLACEHOLDER : $1/eg;
+    $_[0] =~ s/((?<!\\)(['"`]).*?[^\\]\2|\?)/$1 eq '?' ? (++$num_placeholders, PLACEHOLDER) : $1/eg;
     return $num_placeholders;
 }
 
@@ -265,7 +267,7 @@ sub _build_val {
         if (!ref $_) {
             push @$bind, $_;
             '?';
-        } elsif (blessed $_ and $_->isa('DBIx::DBO::Column')) {
+        } elsif (UNIVERSAL::isa($_, 'DBIx::DBO::Column')) {
             $me->_build_col($_);
         } elsif (ref $_ eq 'SCALAR') {
             $$_;
@@ -316,7 +318,7 @@ sub _build_where_chunk {
                 for (my $i = $#whs; $i >= 0; $i--) {
                     # Right now this starts with the last @whs and works backwards
                     # It splices when the ag is the correct AND/OR and the funcs match and all flds match
-                    next if (ref $whs[$i][0] or $ag ne ($whs[$i][7] || _op_ag($whs[$i][0])));
+                    next if ref $whs[$i][0] or $ag ne ($whs[$i][7] || _op_ag($whs[$i][0]));
                     no warnings 'uninitialized';
                     next if $whs[$i][2] ne $fld_func;
                     use warnings 'uninitialized';
@@ -351,11 +353,18 @@ sub _build_quick_where {
     my @where;
     while (my ($col, $val) = splice @_, 0, 2) {
         # FIXME: What about aliases in quick_where?
-        push @where, $me->_build_col($me->_parse_col($col)) .
-            ( defined $val ? (ref $val ne 'SCALAR' or $$val !~ /^\s*(?:NOT\s+)NULL\s*$/is) ?
-                ' = '.$me->_build_val($bind, $me->_parse_val($val)) :
-                ' IS '.$$val :
-                ' IS NULL' );
+        push @where, $me->_build_col($me->_parse_col($col)) . do {
+                if (ref $val eq 'SCALAR' and $$val =~ /^\s*(?:NOT\s+)NULL\s*$/is) {
+                    ' IS ';
+                } elsif (ref $val eq 'ARRAY') {
+                    ' IN ';
+                } elsif (defined $val) {
+                    ' = ';
+                } else {
+                    $val = \'NULL';
+                    ' IS ';
+                }
+            } . $me->_build_val($bind, $me->_parse_val($val));
     }
     join ' AND ', @where;
 }
