@@ -21,6 +21,9 @@ DBIx::DBO::Table - An OO interface to SQL queries and results.  Encapsulates a t
   
   # Quickly display my employee id
   print $table->fetch_value('employee_id', name => 'Vernon');
+
+  # Find the IDs of fired employees
+  my @fired = @{ $table->fetch_column('id', status => 'fired');
   
   # Insert a new row into the table
   $table->insert(employee_id => 007, name => 'James Bond');
@@ -28,6 +31,11 @@ DBIx::DBO::Table - An OO interface to SQL queries and results.  Encapsulates a t
   # Remove rows from the table where the name IS NULL
   $table->delete(name => undef);
 
+=head1 DESCRIPTION
+
+C<Table> objects are mostly used for column references in a C<Query>.
+They can also be used for INSERTs, DELETEs and simple lookups (fetch_*).
+
 =head1 METHODS
 
 =head3 C<new>
@@ -44,7 +52,7 @@ Tables can be specified by their name or an arrayref of schema and table name or
 sub new {
     my ($proto, $dbo, $table) = @_;
     my $class = ref($proto) || $proto;
-    blessed $dbo and $dbo->isa('DBIx::DBO') or ouch 'Invalid DBO Object';
+    UNIVERSAL::isa($dbo, 'DBIx::DBO') or ouch 'Invalid DBO Object';
     (my $schema, $table, my $me) = $dbo->table_info($table) or ouch 'No such table: '.$table;
     $class = $class->_set_dbd_inheritance($dbo->{dbd});
     bless { %$me, Schema => $schema, Name => $table, DBO => $dbo, LastInsertID => undef }, $class;
@@ -254,6 +262,19 @@ sub delete {
     $me->do($sql, undef, @bind);
 }
 
+=head3 C<truncate>
+
+  $table->truncate;
+
+Truncate the table.  Returns true on success or C<undef> on failure.
+
+=cut
+
+sub truncate {
+    my $me = shift;
+    $me->do('TRUNCATE TABLE '.$me->_quoted_name);
+}
+
 =head2 Common Methods
 
 These methods are accessible from all DBIx::DBO* objects.
@@ -314,6 +335,5 @@ Add a multi_insert method for extended INSERTs.
 
 L<DBIx::DBO>
 
-
 =cut
 
